@@ -3,9 +3,10 @@ use strict;
 use warnings;
 package YAML::PP::Constructor;
 
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 use YAML::PP;
+use YAML::PP::Common qw/ PRESERVE_ALL PRESERVE_ORDER PRESERVE_SCALAR_STYLE /;
 use Scalar::Util qw/ reftype /;
 
 use constant DEBUG => ($ENV{YAML_PP_LOAD_DEBUG} or $ENV{YAML_PP_LOAD_TRACE}) ? 1 : 0;
@@ -17,6 +18,10 @@ sub new {
     my ($class, %args) = @_;
 
     my $default_yaml_version = delete $args{default_yaml_version};
+    my $preserve = delete $args{preserve} || 0;
+    if ($preserve == PRESERVE_ALL) {
+        $preserve = PRESERVE_ORDER | PRESERVE_SCALAR_STYLE;
+    }
     my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
     die "Invalid value for cyclic_refs: $cyclic_refs"
         unless $cyclic_refs{ $cyclic_refs };
@@ -30,6 +35,7 @@ sub new {
         default_yaml_version => $default_yaml_version,
         schemas => $schemas,
         cyclic_refs => $cyclic_refs,
+        preserve => $preserve,
     }, $class;
     $self->init;
     return $self;
@@ -42,6 +48,7 @@ sub clone {
         schema => $self->{schema},
         default_yaml_version => $self->{default_yaml_version},
         cyclic_refs => $self->cyclic_refs,
+        preserve => $self->{preserve},
     };
     return bless $clone, ref $self;
 }
@@ -69,12 +76,15 @@ sub set_cyclic_refs { $_[0]->{cyclic_refs} = $_[1] }
 sub yaml_version { return $_[0]->{yaml_version} }
 sub set_yaml_version { $_[0]->{yaml_version} = $_[1] }
 sub default_yaml_version { return $_[0]->{default_yaml_version} }
+sub preserve_order { return $_[0]->{preserve} & PRESERVE_ORDER }
+sub preserve_scalar_style { return $_[0]->{preserve} & PRESERVE_SCALAR_STYLE }
 
 sub document_start_event {
     my ($self, $event) = @_;
     my $stack = $self->stack;
     if ($event->{version_directive}) {
         my $version = $event->{version_directive};
+        $version = "$version->{major}.$version->{minor}";
         if ($self->{schemas}->{ $version }) {
             $self->set_yaml_version($version);
             $self->set_schema($self->schemas->{ $version });
@@ -114,6 +124,10 @@ sub mapping_start_event {
     };
     my $stack = $self->stack;
 
+    if ($self->preserve_order and not tied(%$data)) {
+        tie %$data, 'YAML::PP::Preserve::Hash';
+    }
+
     push @$stack, $ref;
     if (defined(my $anchor = $event->{anchor})) {
         $self->anchors->{ $anchor } = { data => $ref->{data} };
@@ -230,6 +244,13 @@ sub scalar_event {
         $self->anchors->{ $name } = { data => $value, finished => 1 };
     }
     my $last = $self->stack->[-1];
+    if ($self->preserve_scalar_style and not ref $value) {
+        $value = YAML::PP::Preserve::Scalar->new(
+            value => $value,
+            style => $event->{style},
+            tag => $event->{tag},
+        );
+    }
     push @{ $last->{ref} }, $value;
 }
 
@@ -263,6 +284,7 @@ sub alias_event {
 
 sub stringify_complex {
     my ($self, $data) = @_;
+    return $data if (ref $data eq 'YAML::PP::Preserve::Scalar' and $self->preserve_scalar_style);
     require Data::Dumper;
     local $Data::Dumper::Quotekeys = 0;
     local $Data::Dumper::Terse = 1;
