@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Dumper;
 
-our $VERSION = '0.020'; # VERSION
+our $VERSION = '0.022'; # VERSION
 
 use Scalar::Util qw/ blessed refaddr reftype /;
 use YAML::PP;
@@ -27,6 +27,7 @@ sub new {
     my $footer = delete $args{footer};
     $footer = 0 unless defined $footer;
     my $version_directive = delete $args{version_directive};
+    my $preserve = delete $args{preserve};
 
     my $schema = delete $args{schema} || YAML::PP->default_schema(
         boolean => 'perl',
@@ -45,6 +46,7 @@ sub new {
     my $self = bless {
         representer => YAML::PP::Representer->new(
             schema => $schema,
+            preserve => $preserve,
         ),
         version_directive => $version_directive,
         emitter => $emitter,
@@ -98,7 +100,8 @@ sub dump {
             implicit => $header_implicit,
         );
         if ($self->version_directive) {
-            $args{version_directive} = $self->representer->schema->yaml_version;
+            my ($major, $minor) = split m/\./, $self->representer->schema->yaml_version;
+            $args{version_directive} = { major => $major, minor => $minor };
         }
         $self->emitter->document_start_event( \%args );
         $self->init;
